Change Item | PyInventory vMockedVersionString

Skip to main content

# Change Item

## name

- History

MockedCsrfTokenNode

Please correct the errors below.

- Version error: Overwrite version 2 with 1 is forbidden!

## Internals

ID:
ID

- Version changed:

      - 2
      + 1

Version: 1
Internal version number of this entry. Used to protect the overwriting of an older entry.
User:
NormalUser
The user who is the owner of this entry and can manage it (will be set automatically)

## Meta

Create date:
Jan. 1, 2000, 1:10 a.m.
(will be set automatically)
Last update:
Jan. 1, 2000, 1:11 a.m.
(will be set automatically)

## Basic

Kind:
Producer:

- changes between version 2 and 1:

      - "name"
      + "A new Name!"

Name:
Name
Description:
Tags:
FCC ID:
Unique number from the FCC
Parent:
Locations can be nested. Example: The box 12 in cupboard 3
Location:

## Related items

Related items:

No. | Items
--- | ---
1 | name

## Lent

Lent to:
Lent from date:

Lent until date:

## Received

Received from:
Received date:

Received price:

## Handed over

Handed over to:
Handed over date:

Handed over price:

## Images

| Position | Preview | Image | Name | Tags | Delete?
--- | --- | --- | --- | --- | --- | ---
|  | - |  |  |  |

## Files

| Position | File | Name | Tags | Delete?
--- | --- | --- | --- | --- | ---

## Links

| Tags | Name | URL | Position | Delete?
--- | --- | --- | --- | --- | ---

Delete